@@ -1,6 +1,6 @@
 import os, shutil, logging
 
-TAG = 'version_11'
+TAG = 'version_26'
 
 def needed(settings, shared, ports):
   if not settings.BINARYEN: return False
@@ -20,7 +20,7 @@ def get(ports, settings, shared):
     return []
   ports.fetch_project('binaryen', 'https://github.com/WebAssembly/binaryen/archive/' + TAG + '.zip', 'binaryen-' + TAG)
   def create():
-    logging.warning('building port: binaryen')
+    logging.info('building port: binaryen')
     ports.build_native(os.path.join(ports.get_dir(), 'binaryen', 'binaryen-' + TAG))
     # the "output" of this port build is a tag file, saying which port we have
     tag_file = os.path.join(ports.get_dir(), 'binaryen', 'tag.txt')
